RcMacro

Type Alias RcMacro 

pub type RcMacro<'a> = Rc<RefCell<dyn FnMut(MacroContext, TokenStream) + 'a>>;
Macro visitor.

Handle all macro calls, and call appropriate function. on the way, it will find all use items, and add new imports to the list.

Creates new visitor for each function, to avoid mixed use items.

It uses lifetime to allow variable to be captured into closure.

Aliased Type

pub struct RcMacro<'a> { /* private fields */ }